Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/edwh_restic_plugin/__about__.py | 1 | 1 | 0 | 0%
src/edwh_restic_plugin/__init__.py | 0 | 0 | 0 | 100%
src/edwh_restic_plugin/env.py | 60 | 52 | 0 | 13%
src/edwh_restic_plugin/helpers.py | 6 | 1 | 0 | 83%
src/edwh_restic_plugin/repositories/__init__.py | 199 | 98 | 0 | 51%
src/edwh_restic_plugin/repositories/b2.py | 35 | 25 | 0 | 29%
src/edwh_restic_plugin/repositories/local.py | 24 | 13 | 0 | 46%
src/edwh_restic_plugin/repositories/sftp.py | 30 | 21 | 0 | 30%
src/edwh_restic_plugin/repositories/swift.py | 39 | 29 | 0 | 26%
src/edwh_restic_plugin/tasks.py | 56 | 56 | 0 | 0%
Total | 450 | 296 | 0 | 34%

No items found using the specified filter.